pub struct CompositionChildResult {
pub run_id: String,
pub tool_call_id: String,
pub tool_name: String,
pub operation_index: u64,
pub status: ToolCallStatus,
pub raw_output: Option<Value>,
pub error: Option<String>,
pub error_category: Option<ToolCallErrorCategory>,
pub executor: Option<ToolExecutor>,
pub duration_ms: Option<u64>,
pub execution_duration_ms: Option<u64>,
}Expand description
Terminal or intermediate result for a child binding operation. Consumers
should pair this with the corresponding CompositionChildCall to recover
the policy annotations and requested side-effect level for the operation.
Fields
run_id: Stringtool_call_id: Stringtool_name: Stringoperation_index: u64status: ToolCallStatusraw_output: Option<Value>error: Option<String>error_category: Option<ToolCallErrorCategory>executor: Option<ToolExecutor>duration_ms: Option<u64>execution_duration_ms: Option<u64>Trait Implementations
Sourceimpl Clone for CompositionChildResult
impl Clone for CompositionChildResult
Sourcefn clone(&self) -> CompositionChildResult
fn clone(&self) -> CompositionChildResult
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CompositionChildResult
impl Debug for CompositionChildResult
Sourceimpl Default for CompositionChildResult
impl Default for CompositionChildResult
Sourceimpl<'de> Deserialize<'de> for CompositionChildResultwhere
CompositionChildResult: Default,
impl<'de> Deserialize<'de> for CompositionChildResultwhere
CompositionChildResult: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for CompositionChildResult
impl PartialEq for CompositionChildResult
Sourcefn eq(&self, other: &CompositionChildResult) -> bool
fn eq(&self, other: &CompositionChildResult) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompositionChildResult
impl Serialize for CompositionChildResult
impl Eq for CompositionChildResult
impl StructuralPartialEq for CompositionChildResult