conditional_replace_with_hook

Function conditional_replace_with_hook 

pub fn conditional_replace_with_hook<F>(
    path: &Path,
    contents: &[u8],
    options: &ConditionalReplaceOptions,
    before_write: F,
) -> Result<ConditionalReplaceReceipt>
where F: FnOnce(),
Variant used by hosts that must snapshot the pre-image immediately before mutation while the replacement lock is still held.