Op

Enum Op 

#[repr(u8)]
pub enum Op {
Show 102 variants Constant = 0, Nil = 1, True = 2, False = 3, GetVar = 4, DefLet = 5, DefVar = 6, SetVar = 7, PushScope = 8, PopScope = 9, Add = 10, Sub = 11, Mul = 12, Div = 13, Mod = 14, Pow = 15, Negate = 16, Equal = 17, NotEqual = 18, Less = 19, Greater = 20, LessEqual = 21, GreaterEqual = 22, Not = 23, Jump = 24, JumpIfFalse = 25, JumpIfTrue = 26, Pop = 27, Call = 28, TailCall = 29, Return = 30, Closure = 31, BuildList = 32, BuildDict = 33, Subscript = 34, SubscriptOpt = 35, Slice = 36, GetProperty = 37, GetPropertyOpt = 38, SetProperty = 39, SetSubscript = 40, MethodCall = 41, MethodCallOpt = 42, Concat = 43, IterInit = 44, IterNext = 45, Pipe = 46, Throw = 47, TryCatchSetup = 48, PopHandler = 49, Parallel = 50, ParallelMap = 51, ParallelSettle = 52, Spawn = 53, SyncMutexEnter = 54, Import = 55, SelectiveImport = 56, DeadlineSetup = 57, DeadlineEnd = 58, BuildEnum = 59, MatchEnum = 60, PopIterator = 61, GetArgc = 62, CheckType = 63, TryUnwrap = 64, CallSpread = 65, CallBuiltin = 66, CallBuiltinSpread = 67, MethodCallSpread = 68, Dup = 69, Swap = 70, Contains = 71, AddInt = 72, SubInt = 73, MulInt = 74, DivInt = 75, ModInt = 76, AddFloat = 77, SubFloat = 78, MulFloat = 79, DivFloat = 80, ModFloat = 81, EqualInt = 82, NotEqualInt = 83, LessInt = 84, GreaterInt = 85, LessEqualInt = 86, GreaterEqualInt = 87, EqualFloat = 88, NotEqualFloat = 89, LessFloat = 90, GreaterFloat = 91, LessEqualFloat = 92, GreaterEqualFloat = 93, EqualBool = 94, NotEqualBool = 95, EqualString = 96, NotEqualString = 97, Yield = 98, GetLocalSlot = 99, DefLocalSlot = 100, SetLocalSlot = 101,
}
Bytecode opcodes for the Harn VM.

Variants



Constant = 0

Push a constant from the constant pool onto the stack.



Nil = 1

Push nil onto the stack.



True = 2

Push true onto the stack.



False = 3

Push false onto the stack.



GetVar = 4

Get a variable by name (from constant pool).



DefLet = 5

Define a new immutable variable. Pops value from stack.



DefVar = 6

Define a new mutable variable. Pops value from stack.



SetVar = 7

Assign to an existing mutable variable. Pops value from stack.



PushScope = 8

Push a new lexical scope onto the environment stack.



PopScope = 9

Pop the current lexical scope from the environment stack.



Add = 10



Sub = 11



Mul = 12



Div = 13



Mod = 14



Pow = 15



Negate = 16



Equal = 17



NotEqual = 18



Less = 19



Greater = 20



LessEqual = 21



GreaterEqual = 22



Not = 23



Jump = 24

Jump unconditionally. arg: u16 offset.



JumpIfFalse = 25

Jump if top of stack is falsy. Does not pop. arg: u16 offset.



JumpIfTrue = 26

Jump if top of stack is truthy. Does not pop. arg: u16 offset.



Pop = 27

Pop top of stack (discard).



Call = 28

Call a function/builtin. arg: u8 = arg count. Name is on stack below args.



TailCall = 29

Tail call: like Call, but replaces the current frame instead of pushing a new one. Used for return f(x) to enable tail call optimization. For builtins, behaves like a regular Call (no frame to replace).



Return = 30

Return from current function. Pops return value.



Closure = 31

Create a closure. arg: u16 = chunk index in function table.



BuildList = 32

Build a list. arg: u16 = element count. Elements are on stack.



BuildDict = 33

Build a dict. arg: u16 = entry count. Key-value pairs on stack.



Subscript = 34

Subscript access: stack has [object, index]. Pushes result.



SubscriptOpt = 35

Optional subscript (obj?[index]). Like Subscript but pushes nil instead of indexing when the object is nil.



Slice = 36

Slice access: stack has [object, start_or_nil, end_or_nil]. Pushes sublist/substring.



GetProperty = 37

Property access. arg: u16 = constant index (property name).



GetPropertyOpt = 38

Optional property access (?.). Like GetProperty but returns nil instead of erroring when the object is nil. arg: u16 = constant index.



SetProperty = 39

Property assignment. arg: u16 = constant index (property name). Stack: [value] → assigns to the named variable’s property.



SetSubscript = 40

Subscript assignment. arg: u16 = constant index (variable name). Stack: [index, value] → assigns to variable[index] = value.



MethodCall = 41

Method call. arg1: u16 = constant index (method name), arg2: u8 = arg count.



MethodCallOpt = 42

Optional method call (?.). Like MethodCall but returns nil if the receiver is nil instead of dispatching. arg1: u16, arg2: u8.



Concat = 43

String concatenation of N parts. arg: u16 = part count.



IterInit = 44

Set up a for-in loop. Expects iterable on stack. Pushes iterator state.



IterNext = 45

Advance iterator. If exhausted, jumps. arg: u16 = jump offset. Pushes next value and the variable name is set via DefVar before the loop.



Pipe = 46

Pipe: pops [value, callable], invokes callable(value).



Throw = 47

Pop value, raise as error.



TryCatchSetup = 48

Push exception handler. arg: u16 = offset to catch handler.



PopHandler = 49

Remove top exception handler (end of try body).



Parallel = 50

Execute closure N times sequentially, push results as list. Stack: count, closure → result_list



ParallelMap = 51

Execute closure for each item in list, push results as list. Stack: list, closure → result_list



ParallelSettle = 52

Like ParallelMap but wraps each result in Result.Ok/Err, never fails. Stack: list, closure → {results: Result, succeeded: int, failed: int}



Spawn = 53

Store closure for deferred execution, push TaskHandle. Stack: closure → TaskHandle



SyncMutexEnter = 54

Acquire a process-local mutex for the current lexical scope. arg: u16 constant index (key string).



Import = 55

Import a file. arg: u16 = constant index (path string).



SelectiveImport = 56

Selective import. arg1: u16 = path string, arg2: u16 = names list constant.



DeadlineSetup = 57

Pop duration value, push deadline onto internal deadline stack.



DeadlineEnd = 58

Pop deadline from internal deadline stack.



BuildEnum = 59

Build an enum variant value. arg1: u16 = constant index (enum name), arg2: u16 = constant index (variant name), arg3: u16 = field count. Fields are on stack.



MatchEnum = 60

Match an enum pattern. Checks enum_name + variant on the top of stack (dup’d match value). arg1: u16 = constant index (enum name), arg2: u16 = constant index (variant name). If match succeeds, pushes true; else pushes false.



PopIterator = 61

Pop the top iterator from the iterator stack (cleanup on break from for-in).



GetArgc = 62

Push the number of arguments passed to the current function call.



CheckType = 63

Runtime type check on a variable. arg1: u16 = constant index (variable name), arg2: u16 = constant index (expected type name). Throws a TypeError if the variable’s type doesn’t match.



TryUnwrap = 64

Try-unwrap: if top is Result.Ok(v), replace with v. If Result.Err(e), return it.



CallSpread = 65

Call with spread arguments. Stack: [callee, args_list] -> result.



CallBuiltin = 66

Direct builtin call. Followed by u64 builtin ID, u16 name constant, u8 arg count. Runtime still checks closure shadowing before using the ID.



CallBuiltinSpread = 67

Direct builtin spread call. Followed by u64 builtin ID and u16 name constant. Stack: [args_list] -> result.



MethodCallSpread = 68

Method call with spread arguments. Stack: [object, args_list] -> result. Followed by 2 bytes for method name constant index.



Dup = 69

Duplicate top of stack.



Swap = 70

Swap top two stack values.



Contains = 71

Membership test: stack has [item, collection]. Pushes bool. Works for lists (item in list), dicts (key in dict), strings (substr in string), and sets.



AddInt = 72



SubInt = 73



MulInt = 74



DivInt = 75



ModInt = 76



AddFloat = 77



SubFloat = 78



MulFloat = 79



DivFloat = 80



ModFloat = 81



EqualInt = 82



NotEqualInt = 83



LessInt = 84



GreaterInt = 85



LessEqualInt = 86



GreaterEqualInt = 87



EqualFloat = 88



NotEqualFloat = 89



LessFloat = 90



GreaterFloat = 91



LessEqualFloat = 92



GreaterEqualFloat = 93



EqualBool = 94



NotEqualBool = 95



EqualString = 96



NotEqualString = 97



Yield = 98

Yield a value from a generator. Pops value, sends through channel, suspends.



GetLocalSlot = 99

Get a frame-local slot. arg: u16 slot index.



DefLocalSlot = 100

Define or initialize a frame-local slot. Pops value from stack.



SetLocalSlot = 101

Assign an existing frame-local slot. Pops value from stack.