pub struct LogEvent {
pub kind: String,
pub payload: Value,
pub headers: BTreeMap<String, String>,
pub occurred_at_ms: i64,
}Fields
kind: Stringpayload: Valueheaders: BTreeMap<String, String>occurred_at_ms: i64Implementations
Sourceimpl LogEvent
impl LogEvent
pub fn new(kind: impl Into<String>, payload: Value) -> Self
pub fn with_headers(self, headers: BTreeMap<String, String>) -> Self
Sourcepub fn redact_in_place(&mut self, policy: &RedactionPolicy)
pub fn redact_in_place(&mut self, policy: &RedactionPolicy)
Apply the unified redaction policy to this event’s headers and payload. Backends are intentionally left unaware of redaction — emitters that need scrubbed events call this before append, and readers that materialize events for display can apply the policy again as defense in depth.