pub struct AtomSignature {
pub principal_key: [u8; 32],
pub principal_sig: [u8; 64],
pub persona_key: [u8; 32],
pub persona_sig: [u8; 64],
}Expand description
Detached Ed25519 signatures over the AtomId.
Both keys sign the same payload (the 32-byte AtomId). The principal key represents the trust-graph identity that is ultimately accountable for the change; the persona key represents the agent persona that emitted it. Verification requires both signatures to be valid, which lets the trust graph attribute revocations (per-persona rotation) without invalidating atoms whose principal is still trusted.
Fields
principal_key: [u8; 32]principal_sig: [u8; 64]persona_key: [u8; 32]persona_sig: [u8; 64]Trait Implementations
Sourceimpl Clone for AtomSignature
impl Clone for AtomSignature
Sourcefn clone(&self) -> AtomSignature
fn clone(&self) -> AtomSignature
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AtomSignature
impl Debug for AtomSignature
Sourceimpl<'de> Deserialize<'de> for AtomSignature
impl<'de> Deserialize<'de> for AtomSignature
Sourcefn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
fn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
Sourceimpl PartialEq for AtomSignature
impl PartialEq for AtomSignature
Sourcefn eq(&self, other: &AtomSignature) -> bool
fn eq(&self, other: &AtomSignature) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AtomSignature
impl Serialize for AtomSignature
impl Copy for AtomSignature
impl Eq for AtomSignature
impl StructuralPartialEq for AtomSignature