pub struct ComposedPredicateEvaluation {
pub qualified_name: String,
pub logical_name: String,
pub source: PredicateSource,
pub selected_qualified_name: String,
pub selected_source: PredicateSource,
pub result: InvariantResult,
}Expand description
Effective verdict for one predicate evaluation after ancestor composition.
Fields
qualified_name: Stringlogical_name: Stringsource: PredicateSourceselected_qualified_name: StringThe predicate declaration whose verdict governs this evaluation after applying strictness and shallower-tie rules.
selected_source: PredicateSourceresult: InvariantResultTrait Implementations
Sourceimpl Clone for ComposedPredicateEvaluation
impl Clone for ComposedPredicateEvaluation
Sourcefn clone(&self) -> ComposedPredicateEvaluation
fn clone(&self) -> ComposedPredicateEvaluation
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ComposedPredicateEvaluation
impl Debug for ComposedPredicateEvaluation
Sourceimpl<'de> Deserialize<'de> for ComposedPredicateEvaluation
impl<'de> Deserialize<'de> for ComposedPredicateEvaluation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for ComposedPredicateEvaluation
impl PartialEq for ComposedPredicateEvaluation
Sourcefn eq(&self, other: &ComposedPredicateEvaluation) -> bool
fn eq(&self, other: &ComposedPredicateEvaluation) -> bool
self and other values to be equal, and is used by ==.impl Eq for ComposedPredicateEvaluation
impl StructuralPartialEq for ComposedPredicateEvaluation