compile_source_named

Function compile_source_named 

pub fn compile_source_named(
    source: &str,
    pipeline_name: &str,
) -> Result<Chunk, String>
Same as compile_source but compiles a specific named pipeline as the program entry point instead of the default-pipeline-or-first selection rule. Returns a runtime error when no pipeline with pipeline_name exists in the source.