pub fn enter_execution_scope(scope: ExecutionId) -> ExecutionScopeGuardExpand description
Push scope onto the ambient stack for the lifetime of the returned guard.
The innermost entry wins for current_execution_scope.
pub fn enter_execution_scope(scope: ExecutionId) -> ExecutionScopeGuardPush scope onto the ambient stack for the lifetime of the returned guard.
The innermost entry wins for current_execution_scope.