load_crystallization_bundle

Function load_crystallization_bundle 

pub fn load_crystallization_bundle(
    bundle_dir: &Path,
) -> Result<(CrystallizationBundleManifest, Vec<CrystallizationTrace>), VmError>
Read every fixture trace referenced by the bundle manifest. Returns the manifest plus loaded traces, in the order they appear in the manifest. Fixtures with path: None are skipped.