pub struct BundlePromotion {Show 16 fields
pub owner: Option<String>,
pub approver: Option<String>,
pub author: Option<String>,
pub rollout_policy: String,
pub rollback_target: Option<String>,
pub created_at: String,
pub workflow_version: String,
pub package_name: String,
pub sample_count: usize,
pub confidence: f64,
pub shadow_success_count: usize,
pub shadow_failure_count: usize,
pub divergence_history: Vec<PromotionDivergenceRecord>,
pub approval_history: Vec<PromotionApprovalRecord>,
pub criteria: PromotionCriteria,
pub estimated_time_token_savings: SavingsEstimate,
}Fields
owner: Option<String>approver: Option<String>rollout_policy: StringLogical rollout strategy. Defaults to shadow_then_canary. Hosted
surfaces may extend this enum but must keep existing values stable.
rollback_target: Option<String>created_at: Stringworkflow_version: Stringpackage_name: Stringsample_count: usizeconfidence: f64shadow_success_count: usizeshadow_failure_count: usizedivergence_history: Vec<PromotionDivergenceRecord>approval_history: Vec<PromotionApprovalRecord>criteria: PromotionCriteriaestimated_time_token_savings: SavingsEstimateTrait Implementations
Sourceimpl Clone for BundlePromotion
impl Clone for BundlePromotion
Sourcefn clone(&self) -> BundlePromotion
fn clone(&self) -> BundlePromotion
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BundlePromotion
impl Debug for BundlePromotion
Sourceimpl Default for BundlePromotion
impl Default for BundlePromotion
Sourceimpl<'de> Deserialize<'de> for BundlePromotionwhere
BundlePromotion: Default,
impl<'de> Deserialize<'de> for BundlePromotionwhere
BundlePromotion: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for BundlePromotion
impl PartialEq for BundlePromotion
Sourcefn eq(&self, other: &BundlePromotion) -> bool
fn eq(&self, other: &BundlePromotion) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BundlePromotion
impl Serialize for BundlePromotion
impl StructuralPartialEq for BundlePromotion