pub struct CapabilityCeilingViolation {
pub kind: String,
pub detail: String,
}Expand description
One concrete way the patched bundle exceeds the parent ceiling.
kind is a stable enum string so hosts can group/explain them.
Fields
kind: Stringdetail: StringTrait Implementations
Sourceimpl Clone for CapabilityCeilingViolation
impl Clone for CapabilityCeilingViolation
Sourcefn clone(&self) -> CapabilityCeilingViolation
fn clone(&self) -> CapabilityCeilingViolation
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for CapabilityCeilingViolation
impl Debug for CapabilityCeilingViolation
Sourceimpl<'de> Deserialize<'de> for CapabilityCeilingViolation
impl<'de> Deserialize<'de> for CapabilityCeilingViolation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for CapabilityCeilingViolation
impl PartialEq for CapabilityCeilingViolation
Sourcefn eq(&self, other: &CapabilityCeilingViolation) -> bool
fn eq(&self, other: &CapabilityCeilingViolation) -> bool
self and other values to be equal, and is used by ==.impl Eq for CapabilityCeilingViolation
impl StructuralPartialEq for CapabilityCeilingViolation