pub struct TriggerMatchInfo {
pub source: String,
pub event_id: String,
pub filter_summary: String,
}Expand description
What an auto-resume trigger matched against. Carried on a
ResumptionReceipt when a trigger drove the resume so replay can
reproduce the exact match without re-firing the connector.
Fields
source: Stringevent_id: Stringfilter_summary: StringTrait Implementations
Sourceimpl Clone for TriggerMatchInfo
impl Clone for TriggerMatchInfo
Sourcefn clone(&self) -> TriggerMatchInfo
fn clone(&self) -> TriggerMatchInfo
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TriggerMatchInfo
impl Debug for TriggerMatchInfo
Sourceimpl Default for TriggerMatchInfo
impl Default for TriggerMatchInfo
Sourcefn default() -> TriggerMatchInfo
fn default() -> TriggerMatchInfo
Sourceimpl<'de> Deserialize<'de> for TriggerMatchInfo
impl<'de> Deserialize<'de> for TriggerMatchInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for TriggerMatchInfo
impl PartialEq for TriggerMatchInfo
Sourcefn eq(&self, other: &TriggerMatchInfo) -> bool
fn eq(&self, other: &TriggerMatchInfo) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TriggerMatchInfo
impl Serialize for TriggerMatchInfo
impl Eq for TriggerMatchInfo
impl StructuralPartialEq for TriggerMatchInfo