pub struct WorkflowPatch {
pub schema_version: u32,
pub id: String,
pub summary: Option<String>,
pub operations: Vec<WorkflowPatchOperation>,
}Expand description
A bounded, auditable proposal to mutate a workflow bundle.
Patches are flat lists of WorkflowPatchOperations applied in
order. An empty operations list is rejected by apply_workflow_patch
— silent no-ops would let agents claim work they did not do.
Fields
schema_version: u32id: Stringsummary: Option<String>operations: Vec<WorkflowPatchOperation>Trait Implementations
Sourceimpl Clone for WorkflowPatch
impl Clone for WorkflowPatch
Sourcefn clone(&self) -> WorkflowPatch
fn clone(&self) -> WorkflowPatch
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for WorkflowPatch
impl Debug for WorkflowPatch
Sourceimpl Default for WorkflowPatch
impl Default for WorkflowPatch
Sourcefn default() -> WorkflowPatch
fn default() -> WorkflowPatch
Sourceimpl<'de> Deserialize<'de> for WorkflowPatchwhere
WorkflowPatch: Default,
impl<'de> Deserialize<'de> for WorkflowPatchwhere
WorkflowPatch: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for WorkflowPatch
impl PartialEq for WorkflowPatch
Sourcefn eq(&self, other: &WorkflowPatch) -> bool
fn eq(&self, other: &WorkflowPatch) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WorkflowPatch
impl Serialize for WorkflowPatch
impl StructuralPartialEq for WorkflowPatch