pub struct WorkflowPatchBundlePolicyBody {
pub autonomy_tier: Option<String>,
pub tool_policy: Option<BTreeMap<String, Value>>,
pub approval_required: Option<Vec<String>>,
pub retry: Option<Value>,
pub catchup: Option<Value>,
}Expand description
Shape used by WorkflowPatchOperation::UpdateBundlePolicy. Each
field replaces the corresponding WorkflowBundlePolicy field when
Some. The tool_policy and approval_required lists replace
rather than merge to keep the contract obvious — agents that want a
merge should compute and submit the full list.
Fields
autonomy_tier: Option<String>tool_policy: Option<BTreeMap<String, Value>>approval_required: Option<Vec<String>>retry: Option<Value>catchup: Option<Value>Trait Implementations
Sourceimpl Clone for WorkflowPatchBundlePolicyBody
impl Clone for WorkflowPatchBundlePolicyBody
Sourcefn clone(&self) -> WorkflowPatchBundlePolicyBody
fn clone(&self) -> WorkflowPatchBundlePolicyBody
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for WorkflowPatchBundlePolicyBody
impl Default for WorkflowPatchBundlePolicyBody
Sourcefn default() -> WorkflowPatchBundlePolicyBody
fn default() -> WorkflowPatchBundlePolicyBody
Sourceimpl<'de> Deserialize<'de> for WorkflowPatchBundlePolicyBodywhere
WorkflowPatchBundlePolicyBody: Default,
impl<'de> Deserialize<'de> for WorkflowPatchBundlePolicyBodywhere
WorkflowPatchBundlePolicyBody: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for WorkflowPatchBundlePolicyBody
impl PartialEq for WorkflowPatchBundlePolicyBody
Sourcefn eq(&self, other: &WorkflowPatchBundlePolicyBody) -> bool
fn eq(&self, other: &WorkflowPatchBundlePolicyBody) -> bool
self and other values to be equal, and is used by ==.impl StructuralPartialEq for WorkflowPatchBundlePolicyBody