pub struct WorkflowPatchGraphDiff {
pub added_nodes: Vec<String>,
pub added_edges: Vec<WorkflowPatchEdgeRef>,
pub updated_nodes: Vec<String>,
pub updated_capsules: Vec<String>,
pub policy_fields_changed: Vec<String>,
}Expand description
Structural diff between the original and patched workflow graph. Used by host UIs and the patch-authoring skill so a model that proposes a patch can tell at a glance whether its edit produced the shape it intended.
Fields
added_nodes: Vec<String>added_edges: Vec<WorkflowPatchEdgeRef>updated_nodes: Vec<String>updated_capsules: Vec<String>policy_fields_changed: Vec<String>Trait Implementations
Sourceimpl Clone for WorkflowPatchGraphDiff
impl Clone for WorkflowPatchGraphDiff
Sourcefn clone(&self) -> WorkflowPatchGraphDiff
fn clone(&self) -> WorkflowPatchGraphDiff
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for WorkflowPatchGraphDiff
impl Debug for WorkflowPatchGraphDiff
Sourceimpl Default for WorkflowPatchGraphDiff
impl Default for WorkflowPatchGraphDiff
Sourcefn default() -> WorkflowPatchGraphDiff
fn default() -> WorkflowPatchGraphDiff
Sourceimpl<'de> Deserialize<'de> for WorkflowPatchGraphDiff
impl<'de> Deserialize<'de> for WorkflowPatchGraphDiff
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl PartialEq for WorkflowPatchGraphDiff
impl PartialEq for WorkflowPatchGraphDiff
Sourcefn eq(&self, other: &WorkflowPatchGraphDiff) -> bool
fn eq(&self, other: &WorkflowPatchGraphDiff) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for WorkflowPatchGraphDiff
impl Serialize for WorkflowPatchGraphDiff
impl Eq for WorkflowPatchGraphDiff
impl StructuralPartialEq for WorkflowPatchGraphDiff