pub struct RuntimeContentFingerprint {
pub schema: String,
pub content_sha256: String,
pub harn_version: String,
pub embedded_stdlib_sha256: String,
pub compatibility: RuntimeCompatibilityFingerprint,
pub source_revision: Option<String>,
}Expand description
Typed identity of the Harn runtime content linked into an embedding host.
content_sha256 is derived only from compiled/runtime content. The optional
source revision is provenance metadata and deliberately cannot change that
digest by itself.
Fields
schema: Stringcontent_sha256: Stringharn_version: Stringembedded_stdlib_sha256: Stringcompatibility: RuntimeCompatibilityFingerprintsource_revision: Option<String>Trait Implementations
Sourceimpl Clone for RuntimeContentFingerprint
impl Clone for RuntimeContentFingerprint
Sourcefn clone(&self) -> RuntimeContentFingerprint
fn clone(&self) -> RuntimeContentFingerprint
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RuntimeContentFingerprint
impl Debug for RuntimeContentFingerprint
Sourceimpl<'de> Deserialize<'de> for RuntimeContentFingerprint
impl<'de> Deserialize<'de> for RuntimeContentFingerprint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for RuntimeContentFingerprint
impl StructuralPartialEq for RuntimeContentFingerprint