pub struct SessionTimelineCoverage {
pub returned: usize,
pub available: Option<usize>,
pub truncated: bool,
}Expand description
States whether a bounded snapshot covers every matching semantic node.
available is exact when Harn exhausted every selected source. It is None
when Harn stopped after proving that the requested limit omitted evidence.
Fields
returned: usizeavailable: Option<usize>truncated: boolTrait Implementations
Sourceimpl Clone for SessionTimelineCoverage
impl Clone for SessionTimelineCoverage
Sourcefn clone(&self) -> SessionTimelineCoverage
fn clone(&self) -> SessionTimelineCoverage
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SessionTimelineCoverage
impl Debug for SessionTimelineCoverage
Sourceimpl Default for SessionTimelineCoverage
impl Default for SessionTimelineCoverage
Sourcefn default() -> SessionTimelineCoverage
fn default() -> SessionTimelineCoverage
Sourceimpl<'de> Deserialize<'de> for SessionTimelineCoveragewhere
SessionTimelineCoverage: Default,
impl<'de> Deserialize<'de> for SessionTimelineCoveragewhere
SessionTimelineCoverage: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for SessionTimelineCoverage
Sourceimpl PartialEq for SessionTimelineCoverage
impl PartialEq for SessionTimelineCoverage
Sourceimpl Serialize for SessionTimelineCoverage
impl Serialize for SessionTimelineCoverage
impl StructuralPartialEq for SessionTimelineCoverage