pub fn capability_method_manifest_entry(
capability: CapabilityId,
method: &str,
) -> Option<&'static BuiltinManifestEntry>Expand description
Resolve the contract for one typed Harness method without allocation.
pub fn capability_method_manifest_entry(
capability: CapabilityId,
method: &str,
) -> Option<&'static BuiltinManifestEntry>Resolve the contract for one typed Harness method without allocation.