store

Function store 

pub fn store(
    capability: &str,
    operation: &str,
    params: &DictMap,
    value: &VmValue,
)
Memoize a turn-stable host fact for the remainder of the current turn. Non-allowlisted (capability, operation) pairs are ignored, so a caller cannot widen the allowlist by calling this directly. See lookup.