maybe_push_active_step

Function maybe_push_active_step 

pub fn maybe_push_active_step(
    function_name: &str,
    frame_depth: usize,
    args: &[VmValue],
) -> bool
Push an active step onto the stack iff function_name has metadata registered. Returns true when a frame was pushed so the call site can record that fact. Called from Vm::push_closure_frame after the new frame has been added.