pub fn compute_line_diff(
before: &str,
after: &str,
options: LineDiffOptions,
) -> LineDiffExpand description
Compute one line diff and project only the representations a caller needs.
pub fn compute_line_diff(
before: &str,
after: &str,
options: LineDiffOptions,
) -> LineDiffCompute one line diff and project only the representations a caller needs.