pub struct ToolDependencyRangeParams {
pub start: String,
pub end: String,
}Expand description
Argument-key pair describing one inclusive numeric dependency range inside a path-scoped mutating tool call.
Fields
start: StringArgument key whose value is the inclusive start of a dependency range.
end: StringArgument key whose value is the inclusive end of a dependency range.