VmDictExt

Trait VmDictExt 

pub trait VmDictExt {
    // Required methods
    fn put(&mut self, key: &str, value: VmValue);
    fn put_str(&mut self, key: &str, value: impl AsRef<str>);
    fn put_opt_str(&mut self, key: &str, value: Option<impl AsRef<str>>);
    fn put_opt(&mut self, key: &str, value: Option<VmValue>);
    fn put_bool(&mut self, key: &str, value: bool);
    fn put_int(&mut self, key: &str, value: i64);
}
Field-insertion helpers for a VmValue::Dict backing map.

Implemented for any [DictInsert] map (the transient BTreeMap builders and the persistent DictMap), so the methods are unavailable on unrelated maps and cannot be applied by mistake.

Required Methods

fn put(&mut self, key: &str, value: VmValue)

Inserts value under key (owning the key as a String).

fn put_str(&mut self, key: &str, value: impl AsRef<str>)

Inserts a string value built via VmValue::string.

fn put_opt_str(&mut self, key: &str, value: Option<impl AsRef<str>>)

Inserts a string value only when value is Some.

fn put_opt(&mut self, key: &str, value: Option<VmValue>)

Inserts a VmValue only when value is Some.

fn put_bool(&mut self, key: &str, value: bool)

Inserts a boolean value.

fn put_int(&mut self, key: &str, value: i64)

Inserts an integer value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<M: DictInsert> VmDictExt for M