pub fn initialize_runtime_assets()Expand description
Initialize process-wide assets whose construction should happen before an embedding host enters an async request or VM execution stack.
Hosts should call this once at startup. The operation is idempotent, and VM construction retains a fallback for embedders that do not have an explicit bootstrap phase.