Functions
- canonicalize_
json_ schema - Canonicalize a JSON-Schema-shaped value for repeated validation.
- elicitation_
validate - Validate
dataagainst a canonicalized schema. Mirrors theschema_expectsemantics — returns the (possibly defaulted) value on success and a thrown error string on failure. - elicitation_
validate_ schema - Canonicalize a JSON-Schema-shaped value for use as an MCP elicitation
requestedSchema. Reuses the same canonicalizer the rest of the language uses forschema_from_json_schema(...)so behavior is identical between user-facing schema builtins and elicitation. - json_
to_ vm_ value - validate_
value_ against_ canonical_ schema - Validate
dataagainst a schema that was already canonicalized withcanonicalize_json_schema. - validate_
value_ against_ schema - Validate
dataagainst a canonical Harn schema or JSON Schema value.