Module schema

Module schema 

Functions

elicitation_validate
Validate data against a canonicalized schema. Mirrors the schema_expect semantics — returns the (possibly defaulted) value on success and a thrown error string on failure.
elicitation_validate_schema
Canonicalize a JSON-Schema-shaped value for use as an MCP elicitation requestedSchema. Reuses the same canonicalizer the rest of the language uses for schema_from_json_schema(...) so behavior is identical between user-facing schema builtins and elicitation.
json_to_vm_value