pub fn classify_injection(text: &str, threshold_percent: u8) -> DetectorVerdictExpand description
Score text with the active classifier and build a DetectorVerdict,
marking it flagged when the score meets threshold_percent.
pub fn classify_injection(text: &str, threshold_percent: u8) -> DetectorVerdictScore text with the active classifier and build a DetectorVerdict,
marking it flagged when the score meets threshold_percent.