Standard library builtins for the Harn VM.
Each category of builtins lives in its own sub-module.
Functions
- register_
vm_ stdlib - Register all standard builtins on a VM.
Standard library builtins for the Harn VM.
Each category of builtins lives in its own sub-module.