pub fn current_llm_render_context() -> Option<LlmRenderContext>Expand description
Return a clone of the active frame, or None if no LLM context is
in scope. Render entry-points use this to decide whether to inject
the llm binding.
pub fn current_llm_render_context() -> Option<LlmRenderContext>Return a clone of the active frame, or None if no LLM context is
in scope. Render entry-points use this to decide whether to inject
the llm binding.