pub fn maybe_push_active_step(
function_name: &str,
frame_depth: usize,
args: &[VmValue],
) -> boolExpand description
Push an active step onto the stack iff function_name has metadata
registered. Returns true when a frame was pushed so the call site
can record that fact. Called from Vm::push_closure_frame after the
new frame has been added.