pub struct CompiledFunction {
pub name: String,
pub params: Vec<String>,
pub default_start: Option<usize>,
pub chunk: Chunk,
pub is_generator: bool,
}Expand description
A compiled function (closure body).
Fields
name: Stringparams: Vec<String>default_start: Option<usize>Index of the first parameter with a default value, or None if all required.
chunk: Chunkis_generator: boolTrue if the function body contains yield expressions (generator function).